# Example chat

Note this is not a production quality (or secure) chat application but provided as example.

To start up chat web application:
```commandline
uv run uvicorn aegis_chat.chat_app:app --port 9001 --reload
```